# If modifying these scopes, delete your previously saved credentials
# at ~/.credentials/calendar-python-quickstart.json
GOOGLE_API_SCOPES = 'https://www.googleapis.com/auth/calendar'
CLIENT_SECRET_FILE = 'gbcal_client_secret.json'
GOOGLE_API_APP_NAME = 'gcal'
GOOGLE_CALENDAR_NAME = 'gbcal'
